import { Link } from "react-router-dom";
import { openCity } from "./HorizontalTimeline";

interface UrlButtonProps{
    href: string,
    children: string,
  };


export function Villagebutton({ title, source, page }: { title: string; source: string; page:string}) {
  return (
    <Link className="btn village-style-button" role="button" to={page}>
      <img src={source} className="d-block mx-auto mb-2" alt=""></img>
      <h3>{title}</h3>
    </Link>
  )
}

export function Villbuttonrow(){
  return(
      <div className="row align-items-center bottom-buttons">
        <Villagebutton page="/human-practices" source="https://static.igem.wiki/teams/5247/design/icons/humanpractices.png" title="Human Practice"></Villagebutton>
        <Villagebutton page="/team" source="https://static.igem.wiki/teams/5247/design/icons/team.png" title="Team"></Villagebutton>
        <Villagebutton page="/experiments" source="https://static.igem.wiki/teams/5247/design/icons/lab.png" title="Experiments"></Villagebutton>
        <Villagebutton page="/description" source="https://static.igem.wiki/teams/5247/design/icons/dna.png" title="Description"></Villagebutton>
        <Villagebutton page="/engineering" source="https://static.igem.wiki/teams/5247/design/icons/genetic-engineering.png" title="Engineering"></Villagebutton>
        <Villagebutton page="/safety" source="https://static.igem.wiki/teams/5247/design/icons/safety.png" title="Safety"></Villagebutton>
        <Villagebutton page="/results" source="https://static.igem.wiki/teams/5247/design/icons/results.png" title="Results"></Villagebutton>
      </div>  
  )
}


export const UrlButton = ({ href, children }:UrlButtonProps) => {
    return (
      <a href={href} className="url-button">
        {children}
      </a>
    );
  }




export const DownloadLink = ({ url, fileName }: {url: string, fileName: string}) => {
const handleDownload = () => {
    fetch(url)
    .then((response) => response.blob())
    .then((blob) => {
        const url = window.URL.createObjectURL(new Blob([blob]));
        const link = document.createElement("a");
        link.href = url;
        link.download = fileName || "downloaded-file";
        document.body.appendChild(link);

        link.click();

        document.body.removeChild(link);
        window.URL.revokeObjectURL(url);
    })
    .catch((error) => {
        console.error("Error fetching the file:", error);
    });
};
  
return (

    <a type="button" onClick={handleDownload} className="download-butt">
        Download
    </a>

);
};


export function TabButtonRow({data, classy, opentype, closing}: {data: Array<TabDatensatz>, classy?: string, opentype: string, closing: string}){
  let rows = []
  for ( let i = 0;  i < data.length; i++ ){
    if(classy){
      rows.push(<TabButton classy={classy} type={data[i].cssname} name={data[i].buttonname} opentype={opentype} closing={closing}/>)
    }
    else{
      rows.push(<TabButton type={data[i].cssname} name={data[i].buttonname} opentype={opentype} closing={closing}/>)
    }
  }
  return <div className="align-items-center normal-buttons">
    {rows}
  </div>; 
}



interface TabButtonProps{
  classy?: string, 
  closing: string, 
  opentype: string
  /* children?: React.ReactNode,  */
  /* onClick: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void,  */
  name: string,
  type: string
}
// neuer 
export function TabButton({classy, name, closing, opentype, type}:TabButtonProps){
  if (!classy){
    classy = ""
  }
  let classname = "tabbutton " + type + " " + classy; 
  return(
    <>
    <button className={classname} onClick={openTab({cityName: type, cla: opentype, weg: closing })}> {name}</button>
    </>
  )
}

export function HPMoreButton({name}: {name: string}){
  let c = "timelinepersontabs"
  return(
    <button className="tablinks hp-more-button" onClick={openTab({cityName: name, cla: c})}> More</button>
  )
}

export function BFHMoreButton({it}: {it: string}){
  return(
    <button className="tablinks bfh-more-button" onClick={expandIt({it})}> More</button>
  )
}

function expandIt({it}: {it: string}){
  const openit =  (_event : React.MouseEvent<HTMLButtonElement, MouseEvent>) =>{
    console.log(document.getElementById(it))
    console.log(document.getElementById(it)!.style.display)
    if (document.getElementById(it)!.style.display === "block"){
      document.getElementById(it)!.style.display = "none";
    }
    else if(document.getElementById(it)!.style.display === "none"){
      document.getElementById(it)!.style.display = "block";
    }
  }
  return openit; 
}

export function openTab({cityName, cla, weg}:{cityName: string, cla: string, weg?: string}) {
  const opencity =  (event : React.MouseEvent<HTMLButtonElement, MouseEvent>) =>{
    var i, tabcontent, tablinks, wegcontent;
  tabcontent = document.getElementsByClassName(cla);
  for (i = 0; i < tabcontent.length; i++) {
    (tabcontent[i] as HTMLElement).style.display = "none";
  }
  tablinks = document.getElementsByClassName("tabbutton");
  for (i = 0; i < tablinks.length; i++) {
    tablinks[i].className = tablinks[i].className.replace(" active", "");
  }
  if (weg){
    wegcontent  = document.getElementsByClassName(weg);
    for (i = 0; i < wegcontent.length; i++) {
      (wegcontent[i] as HTMLElement).style.display = "none";
    }
  }
  document.getElementById(cityName)!.style.display = "block";
  event.currentTarget.className += " active";
  }
  return opencity; 
}

export function ButtonThree(){
  return(
    <div className="boxy-3">
      <div className="btn-new btn-three">
        <span typeof="button" onClick={openCity({cityName: "about"})}>HOVER ME</span>
      </div>
    </div>
  )
}

export function ButtonTwo(){
  return(
    <div className="boxy-2">
      <div className="btn-new btn-two">
        <span typeof="button" onClick={openCity({cityName: "about"})}>HOVER ME</span>
      </div>
    </div>
  )
}

export function ButtonOne({text, open}: {text:string, open:string}){
  return(
    <div className="boxy-1">
      <span typeof="button" onClick={openFromOtherPage(open)}>
      <div className="btn-new btn-one">
      {text}
      </div></span>
    </div>
  )
}


export function ButtonFourFill(){
  return(
    <a type="button" className="icon icon-fill"><i className="fa fa-home"></i></a>
  )
}

export function ButtonFourEnter(){
  return(
    <a type="button" className="icon icon-enter"><i className="fa fa-home"></i></a>
  )
}
export function ButtonFourExpand(){
  return(
    <a type="button" className="icon icon-expand"><i className="fa fa-home"></i></a>
  )
}
export function ButtonFourCollapse(){
  return(
    <a type="button"  className="icon icon-collapse"><i className="fa fa-home"></i></a>
  )
}
export function ButtonFourRotate(){
  return(
    <a type="button" className="icon icon-rotate"><i className="fa fa-home"></i></a>
  )
}




export function openIt({it}: {it: string}){
  const openit =  (event : React.MouseEvent<HTMLElement, MouseEvent>) => {
   /*  console.log(document.getElementById(it)) */
    console.log(document.getElementById(it)?.className)
    let tabcontent = document.getElementsByClassName("cycletab");
    for (let i = 0; i < tabcontent.length; i++) {
       (tabcontent[i] as HTMLElement).style.display = "none";
     }
    /* console.log(document.getElementById(it)!.style.display) */
      document.getElementById(it)!.style.display = "block";
    
    event.currentTarget.className += " active";
  }
  return openit; 
}

export function openItTwo({it}: {it: string}){
  const openit =  (event : React.MouseEvent<HTMLElement, MouseEvent>) => {
   /*  console.log(document.getElementById(it)) */
    console.log(document.getElementById(it)?.className)
    let tabcontent = document.getElementsByClassName("col outreach");
    for (let i = 0; i < tabcontent.length; i++) {
       (tabcontent[i] as HTMLElement).style.display = "none";
     }
    /* console.log(document.getElementById(it)!.style.display) */
      document.getElementById(it)!.style.display = "block";
    
    event.currentTarget.className += " active";
  }
  return openit; 
}




export function openFromOtherPage(it: string) {
  return (event: React.MouseEvent<HTMLElement> | { currentTarget: HTMLElement }) => {
    // Get all elements with class "cycletab" and hide them
    let tabcontent = document.getElementsByClassName("cycletab");
    for (let i = 0; i < tabcontent.length; i++) {
        (tabcontent[i] as HTMLElement).style.display = "none";
    }
    
    // Show the specific tab content based on the "it" parameter
    const tabToOpen = document.getElementById(it);
    if (tabToOpen) {
        tabToOpen.style.display = "block";

        // Scroll the tab content into view
        const elementTop = tabToOpen.getBoundingClientRect().top + window.pageYOffset;
        const offset = window.innerHeight / 2 - tabToOpen.offsetHeight / 2;
        const scrollPosition = elementTop - offset;

        window.scrollTo({
            top: scrollPosition,
            behavior: 'smooth',
        });
    }

    // Optionally, add an "active" class to the clicked button (if needed)
    const tabs = document.querySelectorAll('.btn-new');
    tabs.forEach(tab => tab.classList.remove('active'));

    if (event.currentTarget) {
        event.currentTarget.classList.add('active');
    }
}
}
