
import { ButtonOne} from "../components/Buttons";
import { useEffect } from "react";
import { useLocation } from "react-router-dom";
import { openFromOtherPage } from "../components/Buttons";
import { useNavigation } from "../utils/useNavigation";

export function Education() {
  const { goToPagesAndOpenTab, goToTextsAndOpenCollapsible } = useNavigation();
  const location = useLocation();
    useEffect(() => {
        const params = new URLSearchParams(location.search);
        const collapseId = params.get('collapseId');
        const tabId = params.get('tab');

        // Scroll to the section specified by collapseId
        if (collapseId) {
            const collapseElement = document.getElementById(collapseId);
            if (collapseElement) {
                const elementTop = collapseElement.getBoundingClientRect().top + window.pageYOffset;
                const offset = window.innerHeight / 2 - collapseElement.offsetHeight / 2;
                const scrollPosition = elementTop - offset;

                window.scrollTo({
                    top: scrollPosition,
                    behavior: 'smooth',
                });
            }
        }

        // Open the tab specified by tabId
        if (tabId) {
            openFromOtherPage(tabId)({ currentTarget: document.getElementById(tabId)! });
        }
    }, [location.search]);

    return (
      <>
        <div>
            <h2>Interviews Page</h2>
            <a onClick={() => goToTextsAndOpenCollapsible("symptoms-collapsible", "/description?collapseId=")}>  {/*   */}
                Go to Texts and Open Collapsible 1
            </a>
        </div>
        <div className="row align-items-center" style={{marginTop: "5vh", marginBottom: "5vh"}}>
        <div className="col">
            <ButtonOne text="Overview" open="overview"></ButtonOne>
          </div>
          <div className="col">
            <ButtonOne text="MukoMove" open="mukomove"></ButtonOne>
          </div>
          <div className="col">
            <ButtonOne text="Teuto ruft!" open="teutoruft"></ButtonOne>
          </div>
          <div className="col">
            <ButtonOne text="Schüler*innen Akademie" open="akademie"></ButtonOne>
          </div>
        </div>
        <div id="overview" className="cycletab" style={{display: "block"}}>
          <h2>Our education and outreach</h2>

          <h2>If not as a special prize - then why?</h2>
        </div>
        <div id="akademie" className="cycletab" style={{display: "none"}}>
          <h2>Student academy on the topic of synthetic biology</h2>
        </div>
        <div id="teutoruft" className="cycletab" style={{display: "none"}}>
          <h2>Educational city tour for young and old</h2>
          <div className="row align-items-center">
              <div className="col">
                <img src="https://static.igem.wiki/teams/5247/photos/edcation-and-outreach/teutoruft-experminet.jpeg"></img>
              </div>
              <div className="col">
              <img src="https://static.igem.wiki/teams/5247/photos/edcation-and-outreach/teutoruft-gruppe.jpeg"></img>
              </div>
            </div>
        </div>
        <div id="mukomove" className="cycletab" style={{display: "none"}}>
          <h2>Cystic fibrosis awareness month</h2>
          <div className="row">
            <div className="col-3">
                <img className="max400" src="https://static.igem.wiki/teams/5247/photos/for-wiki-texts/po-mukomove/wir-plakat-mukomove.jpeg"></img>
            </div>
            <div className="col">
            <h3>What is MUKOMOVE?</h3>
            <p>As part of the cystic fibrosis awareness month May, we took part in this year's <a href="https://www.muko.info/mukomove">MUKOmove</a> from May 8th to May
              12th under the team name iGEM Bielefeld. MUKOmove is a participatory sports initiative organized by 
              <a href="https://www.muko.info/"> Mukoviszidose e.V.</a>, the German Cystic Fibrosis Association, aimed at raising awareness and funds 
              for cystic fibrosis research and support. This annual event encourages individuals and teams to 
              engage in various physical activities, track their movement, and share their experiences online.  </p>
              <button>Spenden</button>
            </div>
          </div>
          <br/> 
          <div className="row">
            <div className="col">
            <h3>Why and in which ways were we invested in MUKOmove? </h3>
          <p>We did not stop at our participation itself – we wanted to make other people from our university and city 
            aware of the event and collect sport hours for cystic fibrosis with them by inviting them to join our team. 
            Our survey about cystic fibrosis awareness and our discussions with <a onClick={() => goToPagesAndOpenTab('InvWesthoff', '/human-practices?tab=')}>Kathrin Westhoff</a>, the head of a 
            practice for physiotherapy in Gütersloh who is also treating young CF patients, showed us how little known 
            this illness still is. Especially the interview with the physiotherapist made us realize how important 
            exercise is for everyone and how it brings a community together – we wanted to establish MUKOmove in 
            Bielefeld. That is why we really got the publicity going by putting up posters and distributing flyers 
            at the university and in our city as you can see in the following picture. </p>
            </div>
            <div className="col-4">
                <img className="max400" src="https://static.igem.wiki/teams/5247/photos/for-wiki-texts/po-mukomove/img-7828.jpeg"></img>
              </div>
          </div>
            <br/> 
          <p>We also called for MUKOmove on our socials and set our team a goal of collecting 240 hours doing sports together, 
            while the entire MUKOmove had a goal of collecting 24,000 sport hours. In cooperation with our university's 
            sports facilities, using their <a href="https://www.uni-bielefeld.de/einrichtungen/hochschulsport/zusatzangebote/houbi/">“HOUBI-Aktivmobil"</a> and other equipment, we organized a team event at the sports 
            ground of our university at the begin of MUKOmove. Everyone was warmly invited to our event on May 8th, and 
            it was a lot of fun to play various sport games together outside in the sun – check out in the following 
            video! </p>
          <div className="row align-items-center">
            <div className="col">
            <img src="https://www.mapcom.com/wp-content/uploads/2015/07/video-placeholder.jpg"></img>
            </div>
          </div>
          <br/>
          <h3>What did we achieve?</h3>
          <p>We are happy to announce that both movement goals were surpassed: Team iGEM Bielefeld was able to collect 358 sport hours, and everyone who took part in MUKOmove together collected 36,542 sport hours!  </p>
          <p>The MUKOmove was therefore a complete success, and we take pride in having contributed to the goal while raising more awareness for cystic fibrosis in our region and Germany as a whole.</p>
          </div>

      </>
    );
  }
  